@@ -103,6 +103,20 @@ test_that("built models can predict correct classes", {
     as.character(predict(mach, array.test)@pred),
     array.test$defineCase
   )
+
+  set.seed(12345)
+  mach <- buildGLM(array.train)
+  expect_equal(
+    as.character(predict(mach, array.test)@pred),
+    array.test$defineCase
+  )
+
+  set.seed(12345)
+  mach <- buildLASSO(array.train, nfolds = 3)
+  expect_equal(
+    as.character(predict(mach, array.test)@pred),
+    array.test$defineCase
+  )
 })
 
 array.test@annot$defineCase[1] <- "Case"
@@ -158,6 +172,20 @@ test_that("built models can detect wrong classes", {
     calcStats(predict(mach, array.test), aucSkip = TRUE)$acc,
     .9
   )
+
+  set.seed(12345)
+  mach <- buildGLM(array.train)
+  expect_equal(
+    calcStats(predict(mach, array.test), aucSkip = TRUE)$acc,
+    .9
+  )
+
+  set.seed(12345)
+  mach <- buildLASSO(array.train)
+  expect_equal(
+    calcStats(predict(mach, array.test), aucSkip = TRUE)$acc,
+    .9
+  )
 })
 
 ###########################################################
